import PubSub from "pubsub-js";
import HistoryTrack from "../layers/HistoryTrack";
import App from "../App";
import MapUtil from "./MapUtil";

export default class HistoryTrackControl{
    /** 
     * 打开历史轨迹。
     */
    initHistoryTrack(){
        PubSub.publish("map.his.init");
    }

    /** 
     * 清空历史轨迹。
     */
    clearHistoryTrack(){
        PubSub.publish("his.play.ctrl", {state: HistoryTrack.HIS_CLEAR});
    }

    /** 
     * 播放历史轨迹。
     */
    playHistoryTrack(){
        setTimeout(() => {
            PubSub.publish("his.play.ctrl", {state: HistoryTrack.HIS_PLAY});
        }, 100);
    }

    /** 
     * 暂停历史轨迹。
     */
    pauseHistoryTrack(){
        PubSub.publish("his.play.ctrl", {state: HistoryTrack.HIS_PAUSE});
    }

    /** 
     * 设置历史轨迹进度。
     * @param {number} value - 进度值0到1
     */
    setHistoryTrackProgress(value){
        PubSub.publish("his.play.ctrl", {progress: value, state: HistoryTrack.HIS_SET_PROGRESS});
    }

    /** 
     * 设置历史轨迹速度。
     * @param {number} speed - 速度值
     */
    setHistoryTrackSpeedMultiply(multi){
        PubSub.publish("his.play.ctrl", {speedMultiply: multi, state: HistoryTrack.HIS_SET_SPEED});
    }

    /** 
     * 设置历史轨迹。
     * @param {Array<[lat: number, lng: number]>} path - 经纬度坐标数组
     * @param {String} src - 移动标识图标路径
     * @param {number} speed - 标识移动速度
     */
    setHistoryPath(path, src, multi = 1){
        setTimeout(() => {
            path = path.map(point => {                
				let latlng = MapUtil.distancePointToLatLng(App.origin, point.x, point.y);
                return {lat: latlng.lat, lng: latlng.lng, time: point.time};
            });
            PubSub.publish("map.his.set", {path: path, src: src, speedMultiply: multi});
        }, 50);
    }
}